.. image:: https://travis-ci.org/dokipen/tubing.svg
.. image:: https://coveralls.io/repos/github/dokipen/tubing/badge.svg?branch=master :target: https://coveralls.io/github/dokipen/tubing?branch=master
Tubing
======
